===================
Django Flex Pub/Sub
===================


.. image:: https://img.shields.io/pypi/v/flex_pubsub.svg
        :target: https://pypi.python.org/pypi/flex_pubsub

.. image:: https://img.shields.io/travis/ali-avani/flex_pubsub.svg
        :target: https://travis-ci.com/ali-avani/flex_pubsub

.. image:: https://readthedocs.org/projects/django-flex-pubsub/badge/?version=latest
        :target: https://django-flex-pubsub.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Django project for using Google Cloud Pub/Sub for handling background and scehduler tasks


* Free software: MIT license
* Documentation: https://django-flex-pubsub.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
